@@ -5,7 +5,7 @@ from typing import TYPE_CHECKING, Any
 import pytest
 from mimesis import Datetime
 
-from tests.utils import TableWithUTCDT, create_db_item_sync
+from tests.utils import PydanticTestSchema, TableWithUTCDT, create_db_item_sync
 
 if TYPE_CHECKING:
     from sqlalchemy.orm import Session
@@ -28,6 +28,7 @@ def table_create(
     ) -> TableWithUTCDT:
         params: dict[str, Any] = dict(
             dt_field=dt_faker.datetime(),
+            pydantic_field=PydanticTestSchema(a=2, b=3, c=4),
         )
         params.update(kwargs)
         return create_db_item_sync(session, TableWithUTCDT, params, commit=commit)
@@ -54,3 +55,20 @@ def test_dt_field(
         assert item.dt_field.tzinfo == UTC
     else:
         assert item.dt_field.tzinfo is None
+
+
+@pytest.mark.parametrize(
+    ("field", "expected_value"),
+    [
+        (PydanticTestSchema(a=255, b=255, c=255), PydanticTestSchema(a=255, b=255, c=255)),
+        ({"a": 255, "b": 255, "c": 255}, PydanticTestSchema(a=255, b=255, c=255)),  # noqa: DTZ005
+    ],
+)
+def test_pydantic_field(
+    field: Any,  # noqa: ANN401
+    expected_value: Any,  # noqa: ANN401
+    db_sync_session: "Session",
+    table_create: "SyncFactoryFunctionProtocol[TableWithUTCDT]",
+) -> None:
+    item = table_create(db_sync_session, pydantic_field=field, commit=True)
+    assert item.pydantic_field == expected_value
